@@ -62,24 +62,32 @@ class BaseTearsheet(object):
         """
         if self._pdf:
             for fignum in plt.get_fignums():
-                self._pdf.savefig(fignum)
+                self._pdf.savefig(fignum, bbox_inches='tight')
             plt.close("all")
             self._pdf.close()
         else:
             plt.show()
 
-    def _y_format_as_percentage(self, axis):
+    def _y_format_as_percentage(self, axis, max_decimal_places=1):
         """
         Sets a Y-axis formatter that converts a decimal to a percentage (e.g.
         0.12 -> 12.0%)
         """
         def format_as_pct(x, pos):
-            # Round to 1 decimal place (12.1%) unless it doesn't matter (12%
+            # Round to max_decimal_places (12.1%) unless it doesn't matter (12%
             # not 12.0%)
-            if round(x,2) == round(x,3):
-                return '{:.0%}'.format(x)
-            else:
-                return '{:.1%}'.format(x)
+            decimal_places = max_decimal_places
+
+            while decimal_places > 0:
+                rounded_result = round(x, decimal_places+2)
+                more_rounded_result = round(x, decimal_places+1)
+
+                if rounded_result != more_rounded_result:
+                    return ('{:.%d%%}' % decimal_places).format(x)
+
+                decimal_places -= 1
+
+            return '{:.0%}'.format(x)
 
         y_axis_formatter = FuncFormatter(format_as_pct)
         axis.yaxis.set_major_formatter(FuncFormatter(y_axis_formatter))
@@ -129,6 +137,8 @@ class BaseTearsheet(object):
 
         if isinstance(performance.cum_returns, pd.DataFrame):
             num_series = len(performance.cum_returns.columns)
+            if performance.benchmark_returns is not None:
+                num_series += 1
             if num_series > 6:
                 color_palette = sns.color_palette("hls", num_series)
 
@@ -147,9 +157,9 @@ class BaseTearsheet(object):
                 axis.set_ylabel("Cumulative return")
 
             include_commissions = (
-                performance.commissions_pct is not None
+                performance.commissions is not None
                 # if all commissions are null/0, don't show them
-                and (performance.commissions_pct.fillna(0) != 0).any())
+                and (performance.commissions.fillna(0) != 0).any())
 
             include_slippage = (
                 performance.slippages is not None
@@ -162,13 +172,11 @@ class BaseTearsheet(object):
                 subplot != 212 and (include_commissions or include_slippage)):
 
                 if include_commissions:
-                    commissions_pct = performance.commissions_pct
-                    cum_commissions_pct = get_cum_returns(commissions_pct, compound=False)
-                    cum_commissions_pct.name = "commissions"
+                    cum_commissions = performance.cum_commissions
+                    cum_commissions.name = "commissions"
 
                 if include_slippage:
-                    slippages = performance.slippages
-                    cum_slippages = get_cum_returns(slippages, compound=False)
+                    cum_slippages = performance.cum_slippages
                     cum_slippages.name = "slippage"
 
                 performance.cum_returns.name = "returns"
@@ -176,7 +184,7 @@ class BaseTearsheet(object):
                 cum_gross_returns = performance.cum_returns
 
                 if include_commissions:
-                    cum_gross_returns = cum_gross_returns.multiply(cum_commissions_pct)
+                    cum_gross_returns = cum_gross_returns.multiply(cum_commissions)
 
                 if include_slippage:
                     cum_gross_returns = cum_gross_returns.multiply(cum_slippages)
@@ -185,7 +193,7 @@ class BaseTearsheet(object):
                 breakdown_parts = [performance.cum_returns, cum_gross_returns]
 
                 if include_commissions:
-                    breakdown_parts.append(cum_commissions_pct)
+                    breakdown_parts.append(cum_commissions)
 
                 if include_slippage:
                     breakdown_parts.append(cum_slippages)
@@ -224,15 +232,15 @@ class BaseTearsheet(object):
                 axis = fig.add_subplot(subplot)
                 axis.set_ylabel("PNL")
                 if (
-                    performance.commissions is not None
+                    performance.commission_amounts is not None
                     # a 212 subplot means a detailed plot, which isn't compatible with
                     # showing commissions
                     and subplot != 212
                     # if all commissions are null/0, don't show them
-                    and (performance.commissions.fillna(0) != 0).any()):
-                    cum_commissions = performance.commissions.cumsum()
+                    and (performance.commission_amounts.fillna(0) != 0).any()):
+                    cum_commissions = performance.cum_commission_amounts
                     cum_commissions.name = "commissions"
-                    cum_pnl = performance.pnl.cumsum()
+                    cum_pnl = performance.cum_pnl
                     cum_pnl.name = "pnl"
                     cum_gross_pnl = cum_pnl + cum_commissions.abs()
                     cum_gross_pnl.name = "gross pnl"
@@ -279,7 +287,7 @@ class BaseTearsheet(object):
 
                 if isinstance(performance.cum_returns, pd.Series):
                     performance.cum_returns.name = "strategy"
-                benchmark_cum_returns = get_cum_returns(performance.benchmark_returns, compound=True)
+                benchmark_cum_returns = performance.benchmark_cum_returns
                 try:
                     vs_benchmark = pd.concat((performance.cum_returns, benchmark_cum_returns), axis=1, sort=True)
                 except TypeError:
