@@ -22,9 +22,11 @@ from .utils import (
     get_rolling_sharpe,
     get_cagr,
     get_cum_returns,
-    get_drawdowns)
+    get_drawdowns,
+    intraday_to_daily)
 
-from quantrocket.moonshot import read_moonshot_csv, intraday_to_daily
+from quantrocket.moonshot import read_moonshot_csv
+from quantrocket.blotter import read_pnl_csv
 
 class DailyPerformance(object):
     """
@@ -49,17 +51,17 @@ class DailyPerformance(object):
     total_holdings : DataFrame, optional
         a Dataframe of the number of holdings
 
-    trades : DataFrame, optional
-        a DataFrame of trades, that is, changes to positions
+    turnover : DataFrame, optional
+        a DataFrame of turnover, that is, changes to positions
+
+    commission_amounts : DataFrame, optional
+        a DataFrame of commission amounts, in the base currency
 
     commissions : DataFrame, optional
-        a DataFrame of commissions, in the base currency
-
-    commissions_pct : DataFrame, optional
-        a DataFrame of commissions, in percentages
+        a DataFrame of commissions, as a proportion of capital
 
     slippages : DataFrame, optional
-        a DataFrame of slippages, in percentages
+        a DataFrame of slippages, as a proportion of capital
 
     benchmark : Series, optional
         a Series of prices for a benchmark
@@ -84,9 +86,9 @@ class DailyPerformance(object):
         net_exposures=None,
         abs_exposures=None,
         total_holdings=None,
-        trades=None,
+        turnover=None,
+        commission_amounts=None,
         commissions=None,
-        commissions_pct=None,
         slippages=None,
         benchmark=None,
         riskfree=0,
@@ -109,7 +111,7 @@ class DailyPerformance(object):
             max_zscore = z_scores.abs().max()
             if isinstance(returns, pd.DataFrame):
                 max_zscore = max_zscore.max()
-            if max_zscore > 10:
+            if max_zscore > 20:
                 import warnings
                 warnings.warn("Found returns which are {0} standard deviations from the "
                               "mean, consider removing them with the `trim_outliers` parameter".format(
@@ -118,16 +120,20 @@ class DailyPerformance(object):
         self.net_exposures = net_exposures
         self.abs_exposures = abs_exposures
         self.total_holdings = total_holdings
-        self.trades = trades
+        self.turnover = turnover
+        self.commission_amounts = commission_amounts
         self.commissions = commissions
-        self.commissions_pct = commissions_pct
         self.slippages = slippages
         self.riskfree = riskfree
         self.compound = compound
         self.rolling_sharpe_window = rolling_sharpe_window
         self._benchmark_prices = benchmark
         self._benchmark_returns = None
+        self._benchmark_cum_returns = None
         self._cum_returns = None
+        self._cum_commissions = None
+        self._cum_slippages = None
+        self._cum_commission_amounts = None
         self._sharpe = None
         self._rolling_sharpe = None
         self._cagr = None
@@ -136,16 +142,26 @@ class DailyPerformance(object):
         self._cum_pnl = None
 
     @classmethod
-    def _from_moonshot(cls, results,
-                       trim_outliers=None,
-                       riskfree=0,
-                       compound=True,
-                       rolling_sharpe_window=200):
+    def _from_moonshot_or_pnl(cls, results,
+                              start_date=None,
+                              end_date=None,
+                              trim_outliers=None,
+                              how_to_aggregate=None,
+                              riskfree=0,
+                              compound=True,
+                              rolling_sharpe_window=200):
         """
-        Creates a DailyPerformance instance from a moonshot backtest results DataFrame.
+        Creates a DailyPerformance instance from a moonshot backtest results
+        DataFrame or a PNL DataFrame.
         """
         if "Time" in results.index.names:
-            results = intraday_to_daily(results)
+            results = intraday_to_daily(results, how=how_to_aggregate)
+
+        if start_date:
+            results = results[results.index.get_level_values("Date") >= start_date]
+
+        if end_date:
+            results = results[results.index.get_level_values("Date") <= end_date]
 
         fields = results.index.get_level_values("Field").unique()
         kwargs = dict(
@@ -155,16 +171,21 @@ class DailyPerformance(object):
             rolling_sharpe_window=rolling_sharpe_window
         )
         kwargs["returns"] = results.loc["Return"]
+
+        if "Pnl" in fields:
+            kwargs["pnl"] = results.loc["Pnl"]
         if "NetExposure" in fields:
             kwargs["net_exposures"] = results.loc["NetExposure"]
         if "AbsExposure" in fields:
             kwargs["abs_exposures"] = results.loc["AbsExposure"]
         if "TotalHoldings" in fields:
             kwargs["total_holdings"] = results.loc["TotalHoldings"]
-        if "Trade" in fields:
-            kwargs["trades"] = results.loc["Trade"]
+        if "Turnover" in fields:
+            kwargs["turnover"] = results.loc["Turnover"]
         if "Commission" in fields:
-            kwargs["commissions_pct"] = results.loc["Commission"]
+            kwargs["commissions"] = results.loc["Commission"]
+        if "CommissionAmount" in fields:
+            kwargs["commission_amounts"] = results.loc["CommissionAmount"].astype(np.float64)
         if "Slippage" in fields:
             kwargs["slippages"] = results.loc["Slippage"]
         if "Benchmark" in fields:
@@ -174,7 +195,10 @@ class DailyPerformance(object):
 
     @classmethod
     def from_moonshot_csv(cls, filepath_or_buffer,
+                          start_date=None,
+                          end_date=None,
                           trim_outliers=None,
+                          how_to_aggregate=None,
                           riskfree=0,
                           compound=True,
                           rolling_sharpe_window=200):
@@ -186,11 +210,22 @@ class DailyPerformance(object):
         filepath_or_buffer : str or file-like object
             filepath or file-like object of the CSV
 
+        start_date : str (YYYY-MM-DD), optional
+            truncate at this start date (otherwise include entire date range)
+
+        end_date : str (YYYY-MM-DD), optional
+            truncate at this end date (otherwise include entire date range)
+
         trim_outliers: int or float, optional
             discard returns that are more than this many standard deviations from
             the mean. Useful for dealing with data anomalies that cause large
             spikes in plots.
 
+        how_to_aggregate : dict, optional
+            a dict of {fieldname: aggregation method} specifying how to aggregate
+            fields from intraday to daily. See the docstring for
+            `moonchart.utils.intraday_to_daily` for more details.
+
         riskfree : float, optional
             the riskfree rate (default 0)
 
@@ -224,18 +259,25 @@ class DailyPerformance(object):
             else:
                 raise
 
-        return cls._from_moonshot(
-            results, trim_outliers=trim_outliers,
+        return cls._from_moonshot_or_pnl(
+            results,
+            start_date=start_date,
+            end_date=end_date,
+            trim_outliers=trim_outliers,
+            how_to_aggregate=how_to_aggregate,
             riskfree=riskfree,
             compound=compound,
             rolling_sharpe_window=rolling_sharpe_window)
 
     @classmethod
     def from_pnl_csv(cls, filepath_or_buffer,
-                          trim_outliers=None,
-                          riskfree=0,
-                          compound=True,
-                          rolling_sharpe_window=200):
+                     start_date=None,
+                     end_date=None,
+                     trim_outliers=None,
+                     how_to_aggregate=None,
+                     riskfree=0,
+                     compound=True,
+                     rolling_sharpe_window=200):
         """
         Creates a DailyPerformance instance from a PNL CSV.
 
@@ -244,9 +286,20 @@ class DailyPerformance(object):
         filepath_or_buffer : str or file-like object
             filepath or file-like object of the CSV
 
+        start_date : str (YYYY-MM-DD), optional
+            truncate at this start date (otherwise include entire date range)
+
+        end_date : str (YYYY-MM-DD), optional
+            truncate at this end date (otherwise include entire date range)
+
         trim_outliers: int or float, optional
             discard returns that are more than this many standard deviations from the mean
 
+        how_to_aggregate : dict, optional
+            a dict of {fieldname: aggregation method} specifying how to aggregate
+            fields from intraday to daily. See the docstring for
+            `moonchart.utils.intraday_to_daily` for more details.
+
         riskfree : float, optional
             the riskfree rate (default 0)
 
@@ -267,47 +320,18 @@ class DailyPerformance(object):
         >>> perf = DailyPerformance.from_pnl_csv("pnl.csv")
         >>> perf.cum_returns.plot()
         """
-        results = read_moonshot_csv(filepath_or_buffer)
+        results = read_pnl_csv(filepath_or_buffer)
 
-        return cls._from_pnl(
-            results, trim_outliers=trim_outliers,
+        return cls._from_moonshot_or_pnl(
+            results,
+            start_date=start_date,
+            end_date=end_date,
+            trim_outliers=trim_outliers,
+            how_to_aggregate=how_to_aggregate,
             riskfree=riskfree,
             compound=compound,
             rolling_sharpe_window=rolling_sharpe_window)
 
-    @classmethod
-    def _from_pnl(cls, results,
-                  trim_outliers=None,
-                  riskfree=0,
-                  compound=True,
-                  rolling_sharpe_window=200):
-        """
-        Creates a DailyPerformance instance from a PNL results DataFrame.
-        """
-        fields = results.index.get_level_values("Field").unique()
-        kwargs = dict(
-            trim_outliers=trim_outliers,
-            riskfree=riskfree,
-            compound=compound,
-            rolling_sharpe_window=rolling_sharpe_window
-        )
-        kwargs["returns"] = results.loc["Return"].astype(np.float64)
-        kwargs["pnl"] = results.loc["Pnl"].astype(np.float64)
-        if "NetExposure" in fields:
-            kwargs["net_exposures"] = results.loc["NetExposure"].astype(np.float64)
-        if "AbsExposure" in fields:
-            kwargs["abs_exposures"] = results.loc["AbsExposure"].astype(np.float64)
-        if "TotalHoldings" in fields:
-            kwargs["total_holdings"] = results.loc["TotalHoldings"].astype(np.float64)
-        if "Commission" in fields:
-            kwargs["commissions_pct"] = results.loc["Commission"].astype(np.float64)
-        if "CommissionAmount" in fields:
-            kwargs["commissions"] = results.loc["CommissionAmount"].astype(np.float64)
-        if "Benchmark" in fields:
-            kwargs["benchmark"] = results.loc["Benchmark"].astype(np.float64)
-
-        return cls(**kwargs)
-
     @property
     def cum_returns(self):
 
@@ -316,6 +340,30 @@ class DailyPerformance(object):
 
         return self._cum_returns
 
+    @property
+    def cum_commissions(self):
+
+        if self._cum_commissions is None and self.commissions is not None:
+            self._cum_commissions = get_cum_returns(self.commissions, compound=False)
+
+        return self._cum_commissions
+
+    @property
+    def cum_commission_amounts(self):
+
+        if self._cum_commission_amounts is None and self.commission_amounts is not None:
+            self._cum_commission_amounts = self.commission_amounts.cumsum()
+
+        return self._cum_commission_amounts
+
+    @property
+    def cum_slippages(self):
+
+        if self._cum_slippages is None and self.slippages is not None:
+            self._cum_slippages = get_cum_returns(self.slippages, compound=False)
+
+        return self._cum_slippages
+
     @property
     def cagr(self):
         if self._cagr is None:
@@ -381,13 +429,21 @@ class DailyPerformance(object):
             import warnings
             warnings.warn("Multiple benchmarks found, only using first ({0})".format(col))
 
-        benchmark_prices = benchmark[col]
+        benchmark_prices = self._benchmark_prices[col]
 
-        self._benchmark_returns = benchmark_prices.pct_change()
+        self._benchmark_returns = benchmark_prices.pct_change().fillna(0)
         self._benchmark_returns.name = "benchmark"
 
         return self._benchmark_returns
 
+    @property
+    def benchmark_cum_returns(self):
+
+        if self._benchmark_cum_returns is None and self._benchmark_returns is not None:
+            self._benchmark_cum_returns = get_cum_returns(self._benchmark_returns, compound=True)
+
+        return self._benchmark_cum_returns
+
 class AggregateDailyPerformance(DailyPerformance):
     """
     Class representing aggregate daily performance.
@@ -454,12 +510,12 @@ class AggregateDailyPerformance(DailyPerformance):
         if performance.pnl is not None:
             self.pnl = performance.pnl.sum(axis=1)
 
+        if performance.commission_amounts is not None:
+            self.commission_amounts = performance.commission_amounts.sum(axis=1)
+
         if performance.commissions is not None:
             self.commissions = performance.commissions.sum(axis=1)
 
-        if performance.commissions_pct is not None:
-            self.commissions_pct = performance.commissions_pct.sum(axis=1)
-
         if performance.slippages is not None:
             self.slippages = performance.slippages.sum(axis=1)
 
@@ -472,5 +528,5 @@ class AggregateDailyPerformance(DailyPerformance):
         if performance.total_holdings is not None:
             self.total_holdings = performance.total_holdings.sum(axis=1)
 
-        if performance.trades is not None:
-            self.trades = performance.trades.sum(axis=1)
+        if performance.turnover is not None:
+            self.turnover = performance.turnover.sum(axis=1)
